%
% Tutorials 07 and 08 / Benchmark No. 1

clc

% benchmark setup:
% number of elements
nelem = 6;

% thermal conductivity
lambda = 2.0;

% heat source
Q = 0.0;

% connectivity matrix:
lm = [1 2 5;
      5 2 6;
      2 3 6;
      6 3 7;
      3 4 7;
      7 4 8];

% vector of code numbers:
cn = [0, 1, 3, 0, 0, 2, 4, 0];

% number of unknowns
nu = 4;
% number of nodes
nn = 8;

% array of coordinates
x =[0.0, 0.1, 0.2, 0.3, 0.0, 0.1, 0.2, 0.3];
y =[0.0, 0.0, 0.0, 0.0, 0.1, 0.1, 0.1, 0.1];

% array of dirichlet b.c.
d =[5.0, 0.0, 0.0, 20.0, 5.0, 0.0, 0.0, 20.0];

ke = zeros(3,3);
k = zeros(nu,nu);
f = zeros(nu,1);

% conductivity matrix and right-hand side vector assembly
for i = 1:nelem
    xe = [x(lm(i,:))];
    ye = [y(lm(i,:))];
    de = [d(lm(i,:))];
    loc = [cn(lm(i,:))];
    ke = heat2_cond(xe,ye,lambda);
    k=assembly(k,ke,loc,i);
    fe = heat2_source(xe,ye,Q);
    f=assemblyf(f,fe,loc,i);
    f=assemblyd(f,ke,de,loc,i);
end

k
f

% solution:
u=k\f;
u

% global vector of nodal temperatures
for i = 1:nn
  t(i) = d(i);
  if cn(i) ~= 0
    t(i) = t(i) + u(cn(i));
  end
end

% printing into a figure
figure;
for i = 1:nelem
  xe = [x(lm(i,:))] ;
  ye = [y(lm(i,:))] ;
  te = [t(lm(i,:))] ;
  XX 	= [xe(1) xe(2) xe(3) xe(1)];
  YY 	= [ye(1) ye(2) ye(3) ye(1)];
  tt 	= [te(1) te(2) te(3) te(1)];
  patch(XX,YY,tt);hold on;
end
title('Temperature distribution'); xlabel('X'); ylabel('Y'); colorbar;
