% function creates right-hand side vector of prescribed heat flux - 2D trinagular element with linear approximation functions
% In:
%   xe - vector of x nodal coordinates (x1,x2,x3)
%   ye - vector of y nodal coordinates (y1,y2,y3)
%   q  - prescribed heat flux
%   b1,b2,b3 - the edge, where the flux is prescribed - only values 0 or 1
%
% Out:
%   ff - right-hand vector of nodal fluxes (3,1)
%
function ff = heat2_flux (xe,ye,q,b1,b2,b3)

le = length_triangle(xe,ye);

ff = -q*(b1*[ le(1)/2 ; le(1)/2 ; 0] + b2*[ 0 ; le(2)/2 ; le(2)/2] + b3*[ le(3)/2 ; 0 ; le(3)/2 ]);
end


