% function creates right-hand side vector of newton condition - 2D trinagular element with linear approximation functions
% In:
%   xe - vector of x nodal coordinates (x1,x2,x3)
%   ye - vector of y nodal coordinates (y1,y2,y3)
%   alpha - heat transfer coeficient
%   b1,b2,b3 - the edge, where the flux is prescribed - only values 0 or 1
%
% Out:
%   ff - right-hand vector of nodal fluxes (3,1)
%
function ff = heat2_newton (xe,ye,alpha,b1,b2,b3)

le = length_triangle(xe,ye)

ff = zeros (3,3) ;
ff = ff+alpha*b1*le(1)*[1/3,1/6,0; 1/6,1/3,0; 0,0,0];
ff = ff+alpha*b2*le(2)*[ 0,0,0; 0,1/3,1/6; 0,1/6,1/3];
ff = ff+alpha*b3*le(3)*[ 1/3,0,1/6; 0,0,0; 1/6,0,1/3];

end


